==> psyneulink-0.15.1.0.tar.gz: psyneulink-0.15.1.0/Scripts/Examples/Rumelhart Semantic Network.py <==
from psyneulink import *

# This script implements the following network, first described in Rumelhart and Todd
# (Rumelhart, D. E., & Todd, P. M. (1993). Learning and connectionist representations. Attention and performance XIV:
#  Synergies in experimental psychology, artificial intelligence, and cognitive neuroscience, 3-30).

# Semantic Network:

#    (REP_OUT)  (PROP_OUT) (QUAL_OUT) (ACT_OUT)
#  Represention  Property    Quality   Action
#           \________\_________/________/
#                        |
#                 Relations_Hidden
#                   _____|_____
#                  /           \
#   Representation_Hidden  Relations_Input
#                /           (REL_IN)
#               /
#   Representation_Input (REP_IN)

# Construct Mechanisms
rep_in = TransferMechanism(size=10, name='REP_IN')
rel_in = TransferMechanism(size=11, name='REL_IN')
rep_hidden = TransferMechanism(size=4, function=Logistic, name='REP_HIDDEN')
rel_hidden = TransferMechanism(size=5, function=Logistic, name='REL_HIDDEN')
rep_out = TransferMechanism(size=10, function=Logistic, name='REP_OUT')
prop_out = TransferMechanism(size=12, function=Logistic, name='PROP_OUT')
qual_out = TransferMechanism(size=13, function=Logistic, name='QUAL_OUT')
act_out = TransferMechanism(size=14, function=Logistic, name='ACT_OUT')

# Construct Composition
comp = Composition(name='Rumelhart Semantic Network')
comp.add_backpropagation_learning_pathway(pathway=[rel_in, rel_hidden])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, rep_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, prop_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, qual_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, act_out])
comp.add_backpropagation_learning_pathway(pathway=[rep_in, rep_hidden, rel_hidden])
comp.show_graph()

==> psyneulink-0.15.3.0.tar.gz: psyneulink-0.15.3.0/Scripts/Examples/Rumelhart Semantic Network.py <==
from psyneulink import *

# This script implements the following network, first described in Rumelhart and Todd
# (Rumelhart, D. E., & Todd, P. M. (1993). Learning and connectionist representations. Attention and performance XIV:
#  Synergies in experimental psychology, artificial intelligence, and cognitive neuroscience, 3-30).

# Semantic Network:

#    (REP_OUT)  (PROP_OUT) (QUAL_OUT) (ACT_OUT)
#  Represention  Property    Quality   Action
#           \________\_________/________/
#                        |
#                 Relations_Hidden
#                   _____|_____
#                  /           \
#   Representation_Hidden  Relations_Input
#                /           (REL_IN)
#               /
#   Representation_Input (REP_IN)

# Construct Mechanisms
rep_in = TransferMechanism(input_shapes=10, name='REP_IN')
rel_in = TransferMechanism(input_shapes=11, name='REL_IN')
rep_hidden = TransferMechanism(input_shapes=4, function=Logistic, name='REP_HIDDEN')
rel_hidden = TransferMechanism(input_shapes=5, function=Logistic, name='REL_HIDDEN')
rep_out = TransferMechanism(input_shapes=10, function=Logistic, name='REP_OUT')
prop_out = TransferMechanism(input_shapes=12, function=Logistic, name='PROP_OUT')
qual_out = TransferMechanism(input_shapes=13, function=Logistic, name='QUAL_OUT')
act_out = TransferMechanism(input_shapes=14, function=Logistic, name='ACT_OUT')

# Construct Composition
comp = Composition(name='Rumelhart Semantic Network')
comp.add_backpropagation_learning_pathway(pathway=[rel_in, rel_hidden])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, rep_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, prop_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, qual_out])
comp.add_backpropagation_learning_pathway(pathway=[rel_hidden, act_out])
comp.add_backpropagation_learning_pathway(pathway=[rep_in, rep_hidden, rel_hidden])
comp.show_graph()
